import React, { useState, useEffect } from 'react';
import { MapPin, Search, X, Loader2, Sunset } from 'lucide-react';
import { useSunsetStore, LOCATION_EXPIRY_DAYS } from '../store';
import axios from 'axios';

interface LocationPromptProps {
  onClose?: () => void;
  isChangingLocation?: boolean;
}

export function LocationPrompt({ onClose, isChangingLocation }: LocationPromptProps) {
  const [location, setLocation] = useState('');
  const [isSearching, setIsSearching] = useState(false);
  const [isGettingLocation, setIsGettingLocation] = useState(false);
  const [error, setError] = useState<string | null>(null);
  const setStoreLocation = useSunsetStore((state) => state.setLocation);

  useEffect(() => {
    // Skip if user is explicitly changing location
    if (isChangingLocation) return;

    // Check if the browser supports the permissions API
    if ('permissions' in navigator && 'query' in navigator.permissions) {
      navigator.permissions.query({ name: 'geolocation' })
        .then((result) => {
          if (result.state === 'granted') {
            // Permission is already granted, automatically get location
            setIsGettingLocation(true);
            navigator.geolocation.getCurrentPosition(
              (position) => {
                setStoreLocation({
                  latitude: position.coords.latitude,
                  longitude: position.coords.longitude,
                });
                setIsGettingLocation(false);
                onClose?.();
              },
              (error) => {
                console.error('Error getting location:', error);
                setError('Could not access your location. Please try entering it manually.');
                setIsGettingLocation(false);
              }
            );
          }
        })
        .catch(() => {
          // Permissions API failed, fallback to normal flow
          console.log('Permissions API not supported');
        });
    }
  }, [isChangingLocation, setStoreLocation, onClose]);

  const requestLocation = () => {
    if ('geolocation' in navigator) {
      setIsGettingLocation(true);
      setError(null);
      
      navigator.geolocation.getCurrentPosition(
        (position) => {
          setStoreLocation({
            latitude: position.coords.latitude,
            longitude: position.coords.longitude,
          });
          setIsGettingLocation(false);
          onClose?.();
        },
        (error) => {
          console.error('Error getting location:', error);
          setError('Could not access your location. Please try entering it manually.');
          setIsGettingLocation(false);
        },
        {
          enableHighAccuracy: true,
          timeout: 10000,
          maximumAge: 24 * 60 * 60 * 1000 // Cache for 24 hours
        }
      );
    }
  };

  const handleManualLocation = async (e: React.FormEvent) => {
    e.preventDefault();
    if (!location.trim()) return;

    setIsSearching(true);
    setError(null);

    try {
      const response = await axios.get(
        `https://api.openweathermap.org/geo/1.0/direct?q=${encodeURIComponent(location)}&limit=1&appid=${import.meta.env.VITE_OPENWEATHER_API_KEY}`
      );

      if (response.data && response.data.length > 0) {
        const { lat, lon } = response.data[0];
        setStoreLocation({
          latitude: lat,
          longitude: lon,
        });
        onClose?.();
      } else {
        setError('Location not found. Please try a different search term.');
      }
    } catch (err) {
      setError('Error searching for location. Please try again.');
    } finally {
      setIsSearching(false);
    }
  };

  return (
    <div className="fixed inset-0 flex items-center justify-center p-4 z-50">
      <div className={`max-w-md w-full backdrop-blur-xl bg-white/10 rounded-2xl p-8 text-white shadow-2xl transform transition-all ${isChangingLocation ? 'scale-95' : ''}`}>
        <div className="flex flex-col items-center text-center">
          {isChangingLocation && (
            <button
              onClick={onClose}
              className="absolute top-4 right-4 p-1 rounded-full hover:bg-white/10 transition-colors"
            >
              <X className="w-5 h-5" />
            </button>
          )}
          
          <div className="mb-6">
            <Sunset className="w-24 h-24 text-yellow-400" aria-label="Sunset Today Logo" />
          </div>
          <h2 className="text-3xl font-bold mb-4">
            {isChangingLocation ? 'Change Location' : 'Welcome to Sunset Today'}
          </h2>
          {!isChangingLocation && (
            <p className="text-lg text-white/80 mb-8">
              Discover the most beautiful sunsets in your area with our daily beauty ratings and forecasts.
            </p>
          )}
          
          <button
            onClick={requestLocation}
            disabled={isGettingLocation}
            className="flex items-center space-x-2 bg-white/20 hover:bg-white/30 transition-colors px-4 sm:px-6 py-3 rounded-lg text-base sm:text-lg font-medium backdrop-blur-sm w-full justify-center mb-4 hover:scale-105 transform duration-200 disabled:opacity-70 disabled:hover:scale-100 disabled:cursor-wait"
          >
            {isGettingLocation ? (
              <>
                <Loader2 className="w-6 h-6 animate-spin" />
                <span className="whitespace-nowrap">Updating Location...</span>
              </>
            ) : (
              <>
                <MapPin className="w-6 h-6" />
                <span className="whitespace-nowrap">Share Location</span>
              </>
            )}
          </button>

          <div className="w-full">
            <div className="relative flex items-center">
              <div className="absolute inset-0 flex items-center">
                <div className="w-full border-t border-white/20"></div>
              </div>
              <div className="relative flex justify-center text-sm w-full">
                <span className="px-2 bg-transparent text-white/60">or</span>
              </div>
            </div>

            <form onSubmit={handleManualLocation} className="mt-4 space-y-4">
              <div className="relative">
                <input
                  type="text"
                  value={location}
                  onChange={(e) => setLocation(e.target.value)}
                  placeholder="Enter city name..."
                  className="w-full bg-white/10 border border-white/20 rounded-lg px-4 py-3 text-white placeholder-white/50 focus:outline-none focus:ring-2 focus:ring-white/30 transition-all duration-200"
                />
              </div>
              <button
                type="submit"
                disabled={isSearching}
                className="flex items-center justify-center space-x-2 bg-white/20 hover:bg-white/30 transition-all duration-200 px-4 sm:px-6 py-3 rounded-lg text-base sm:text-lg font-medium backdrop-blur-sm w-full disabled:opacity-50 disabled:cursor-not-allowed hover:scale-105 transform"
              >
                {isSearching ? (
                  <>
                    <Loader2 className="w-5 h-5 animate-spin" />
                    <span className="whitespace-nowrap">Searching...</span>
                  </>
                ) : (
                  <>
                    <Search className="w-5 h-5" />
                    <span className="whitespace-nowrap">Search Location</span>
                  </>
                )}
              </button>
            </form>

            {error && (
              <div className="mt-4 text-red-300 text-sm text-center bg-red-500/10 p-3 rounded-lg">
                {error}
              </div>
            )}
          </div>

          {!isChangingLocation && (
            <p className="mt-4 text-sm text-white/60">
              Your location will be remembered for {LOCATION_EXPIRY_DAYS} days
            </p>
          )}
        </div>
      </div>
    </div>
  );
}